@@ -1,9 +1,9 @@
 #!/usr/bin/env python
 
-from .processor import *
-
-from .downloader import *
-
-from .version import *
 from .common import *
-from .__main__ import *
+from .version import *
+
+# Easy import
+#from .cli_wrapper.converter import *
+#from .cli_wrapper.player import *
+from .downloader import *
